@@ -1,6 +1,6 @@
 !--
 !----------------------------------------------------------------------
-!     Copyright (c) 2001-2009 Shin-ichi Takehiro. All rights reserved.
+!     Copyright (c) 2001-2011 Shin-ichi Takehiro. All rights reserved.
 !----------------------------------------------------------------------
 !
 !ɽ  ae_module
@@ -33,6 +33,7 @@
 !      2009/01/09  ݹ  ae_Initial åդɲ
 !      2009/01/23  ʿ rdoc Ѥ˥ɥȤ
 !      2009/09/09  ݹ  Ȥ
+!      2011/12/03  ݹ  ִؿɲ
 !
 !++
 module ae_module
@@ -136,6 +137,11 @@ module ae_module
   ! a_Int_ag, a_Avr_ag :: 1 ʻǡ¤ 2 ʬʿ
   ! Int_g, Avr_g       :: 1 ʻǡʬʿ
   !
+  !==== 
+  !
+  ! Interpolate_e      :: ڥȥǡκɸͤ(1 )
+  ! a_Interpolate_ae   :: ڥȥǡκɸͤ(2 )
+  !
   !
   use dc_message
   implicit none
@@ -145,6 +151,7 @@ module ae_module
   public ag_ae, ae_ag, g_e, e_g           ! Ѵ
   public ae_Dx_ae, e_Dx_e                 ! ʬ
   public a_Int_ag, Int_g, a_Avr_ag, Avr_g ! ʬʿ
+  public Interpolate_e, a_Interpolate_ae  ! 
   public g_X, g_X_Weight                  ! ɸѿ
 
   integer            :: im=32             ! ʻο
@@ -204,7 +211,7 @@ module ae_module
       g_X_Weight = xl/im
 
       call MessageNotify(&
-        'M','ae_initial','ae_module (2009/01/09) is initialized')
+        'M','ae_initial','ae_module (2011/12/03) is initialized')
 
     end subroutine ae_Initial
 
@@ -447,4 +454,51 @@ module ae_module
 
     end function Avr_g
 
+  !--------------- ַ׻ -----------------
+    function Interpolate_e(e_data,xval)
+      real(8), dimension(-km:km), intent(IN) :: e_data
+      !(in) ϥաꥨǡ
+
+      real(8), intent(in)                    :: xval
+      ! ֤κɸ
+
+      real(8)                                :: Interpolate_e
+      ! ֤̤
+
+      integer :: k
+      ! DO ʸѿ
+
+      Interpolate_e = e_data(0)
+
+      do k=1,km
+         Interpolate_e = Interpolate_e &
+              + 2.0d0 * (   e_data(k)  * cos(2*PI*k/xl*xval) &
+                          - e_data(-k) * sin(2*PI*k/xl*xval) )
+      enddo
+
+    end function Interpolate_e
+
+    function a_Interpolate_ae(ae_data,xval)
+      real(8), dimension(:,-km:), intent(IN)   :: ae_data
+      !(in) ϥաꥨǡ
+
+      real(8), intent(in)                      :: xval
+      ! ֤κɸ
+
+      real(8), dimension(size(ae_data,1))      :: a_Interpolate_ae
+      ! ֤̤
+
+      integer :: k
+      ! DO ʸѿ
+
+      a_Interpolate_ae = ae_data(:,0)
+
+      do k=1,km
+         a_Interpolate_ae = a_Interpolate_ae &
+              + 2.0d0 * (   ae_data(:,k)  * cos(2*PI*k/xl*xval) &
+                          - ae_data(:,-k) * sin(2*PI*k/xl*xval) )
+      enddo
+
+    end function a_Interpolate_ae
+
   end module ae_module
