@@ -24,6 +24,7 @@
 !      2007/11/21  ݹ  ֥롼å
 !      2009/01/09  ݹ  esc_Initial åդɲ
 !      2009/01/29  ʿ Ȥ RDoc Ѥ˽
+!      2009/07/30  ݹ   ΰѿѹ(for OpenMP)
 !
 !++
 module esc_module
@@ -31,7 +32,7 @@ module esc_module
   != esc_module
   !
   ! Authors:: Shin-ichi Takehiro, Youhei SASAKI
-  ! Version:: $Id: esc_module.f90,v 1.14 2009-02-28 21:33:46 uwabami Exp $
+  ! Version:: $Id: esc_module.f90,v 1.15 2009-07-30 12:50:22 takepiro Exp $
   ! Copyright&License:: See COPYRIGHT[link:../COPYRIGHT]
   !
   !== 
@@ -209,10 +210,6 @@ module esc_module
       xl = xmax-xmin ; yl = ymax-ymin
 
       allocate(tj(jm*6),ti(im*2))
-      allocate(wg((jm+1)*im))
-      allocate(ws((2*km+1)*(lm+1)),wgj((jm+1)*im*3))
-      allocate(yx_work(0:jm,0:im-1))
-      allocate(es_work(-km:km,lm),ec_work(-km:km,0:lm))
 
       call c2init(jm,im,itj,tj,iti,ti)
 
@@ -235,7 +232,9 @@ module esc_module
       yx_X = spread(x_X,1,jm+1)
       yx_Y = spread(y_Y,2,im)
 
-      call MessageNotify('M','esc_initial','esc_module (2009/01/09) is initialized')
+      call MessageNotify('M','esc_initial', &
+           'esc_module (2009/07/30) is initialized')
+
     end subroutine esc_Initial
 
   !--------------- Ѵ -----------------
@@ -249,6 +248,9 @@ module esc_module
       real(8), dimension(-km:km,lm), intent(in)    :: es
       !(in) SIN(Y)ڥȥǡ
 
+      real(8)                                      :: wg((jm+1)*im)
+      ! ΰ
+
       call c2s2ga(lm,km,jm,im,es,yx_es,wg,itj,tj,iti,ti,1)
     end function yx_es
 
@@ -262,6 +264,9 @@ module esc_module
       real(8), dimension(-km:km,0:lm), intent(in)  :: ec
       !(in) COS(Y)ڥȥǡ
 
+      real(8)                                      :: wg((jm+1)*im)
+      ! ΰ
+
       call c2s2ga(lm,km,jm,im,ec,yx_ec,wg,itj,tj,iti,ti,2)
     end function yx_ec
 
@@ -275,6 +280,10 @@ module esc_module
       real(8), dimension(0:jm,0:im-1), intent(in)  :: yx
       !(in) ʻǡ
 
+      real(8)                                      :: wg((jm+1)*im)
+      real(8)                                      :: yx_work(0:jm,0:im-1)
+      ! ΰ
+
       yx_work = yx
       call c2g2sa(lm,km,jm,im,yx_work,es_yx,wg,itj,tj,iti,ti,1)
     end function es_yx
@@ -289,6 +298,10 @@ module esc_module
       real(8), dimension(0:jm,0:im-1), intent(in)  :: yx
       !(out) ʻǡ
 
+      real(8)                                      :: wg((jm+1)*im)
+      real(8)                                      :: yx_work(0:jm,0:im-1)
+      ! ΰ
+
       yx_work = yx
       call c2g2sa(lm,km,jm,im,yx_work,ec_yx,wg,itj,tj,iti,ti,2)
     end function ec_yx
@@ -528,6 +541,11 @@ module esc_module
       real(8), dimension(-km:km,lm), intent(in)    :: es_A,es_B
       !(in) 2Ĥ SIN(Y)ϥڥȥǡ
 
+      real(8)                                      :: ws((2*km+1)*(lm+1))
+      real(8)                                      :: wgj((jm+1)*im*3)
+      real(8)                                      :: es_work(-km:km,lm)
+      ! ΰ
+
       integer k,l
 
       call c2ajcb(lm,km,jm,im,es_A,es_B,es_work,ws,wgj,itj,tj,iti,ti)
@@ -559,6 +577,11 @@ module esc_module
       real(8), dimension(-km:km,0:lm), intent(in)  :: ec
       !(in) 2ܤ COS(Y)ϥڥȥǡ
 
+      real(8)                                      :: ws((2*km+1)*(lm+1))
+      real(8)                                      :: wgj((jm+1)*im*3)
+      real(8)                                      :: ec_work(-km:km,0:lm)
+      ! ΰ
+
       integer k,l
 
       call c2ajcc(lm,km,jm,im,es,ec,ec_work,ws,wgj,itj,tj,iti,ti)
