@@ -1,19 +1,19 @@
 !--
 !----------------------------------------------------------------------
-! Copyright(c) 2002-2010 SPMDODEL Development Group. All rights reserved.
+! Copyright(c) 2002-2011 SPMDODEL Development Group. All rights reserved.
 !----------------------------------------------------------------------
 !
 !ɽ  et_module
 !      2 ϩΰ, Fourier Ÿ + Chebyshev Ÿˡ
 !
 !      spml/et_module ⥸塼 2 ϩΰǤήαư
-!      ڥȥˡˤͷ׻¹Ԥ뤿 Fortran90 ؿ󶡤. 
+!      ڥȥˡˤͷ׻¹Ԥ뤿 Fortran90 ؿ󶡤.
 !      Ūʶ򰷤 X ؤΥաꥨѴȶɤ򰷤
 !      Y ΥӥѴѤΥڥȥ׻ΤΤޤޤ
-!      ؿ󶡤. 
+!      ؿ󶡤.
 !
-!       ae_module, at_module ѤƤ. 
-!      ǲǤϥաꥨѴӥӥѴΥ󥸥Ȥ 
+!       ae_module, at_module ѤƤ.
+!      ǲǤϥաꥨѴӥӥѴΥ󥸥Ȥ
 !      ISPACK/FTPACK  Fortran77 ֥롼ѤƤ.
 !
 !
@@ -31,6 +31,8 @@
 !      2009/01/29  ʿ Ȥ RDoc Ѥ˽
 !      2009/07/31  ݹ  ׻ threadprivate (OpenMP)
 !      2010/03/10  ʿ  threadprivate (ѥ¸)
+!      2011/03/06  ʿ 凉å, RR ǥեȤ.
+!      2011/12/03  ݹ  ִؿɲ
 !
 !++
 module et_module
@@ -38,7 +40,7 @@ module et_module
   != et_module
   !
   ! Authors:: Shin-ichi Takehiro, Youhei SASAKI
-  ! Version:: $Id: et_module.f90,v 1.18 2010-03-02 10:09:03 uwabami Exp $
+  ! Version:: $Id: et_module.f90,v 1.19 2011-03-08 05:26:15 uwabami Exp $
   ! Copyright&License:: See COPYRIGHT[link:../COPYRIGHT]
   !
   !== 
@@ -46,13 +48,13 @@ module et_module
   ! 2 ϩΰ, Fourier Ÿ + Chebyshev Ÿˡ
   !
   ! spml/et_module ⥸塼 2 ϩΰǤήαư
-  ! ڥȥˡˤͷ׻¹Ԥ뤿 Fortran90 ؿ󶡤. 
+  ! ڥȥˡˤͷ׻¹Ԥ뤿 Fortran90 ؿ󶡤.
   ! Ūʶ򰷤 X ؤΥաꥨѴȶɤ򰷤
   ! Y ΥӥѴѤΥڥȥ׻ΤΤޤޤ
-  ! ؿ󶡤. 
+  ! ؿ󶡤.
   !
-  !  ae_module, at_module ѤƤ. 
-  ! ǲǤϥաꥨѴӥӥѴΥ󥸥Ȥ 
+  !  ae_module, at_module ѤƤ.
+  ! ǲǤϥաꥨѴӥӥѴΥ󥸥Ȥ
   ! ISPACK/FTPACK  Fortran77 ֥롼ѤƤ.
   !
   !== ؿѿ̾ȷˤĤ
@@ -65,7 +67,7 @@ module et_module
   !   x_  :: X  1 ʻǡ
   !   y_  :: Y  1 ʻǡ
   !
-  ! * ؿ̾δ֤ʸ(Dx, Dy, Lapla, LaplaInv, Jacobian), 
+  ! * ؿ̾δ֤ʸ(Dx, Dy, Lapla, LaplaInv, Jacobian),
   !   δؿκѤɽƤ.
   !
   ! * ؿ̾κǸ (_et_et, _et, _yx, _x, _y) , ѿΥڥȥǡ
@@ -79,16 +81,16 @@ module et_module
   !=== ƥǡμ
   !
   ! * yx : 2 ʻǡ.
-  !   * ѿμȼ real(8), dimension(0:jm,0:im-1). 
+  !   * ѿμȼ real(8), dimension(0:jm,0:im-1).
   !   * im, jm Ϥ줾 X, Y ɸγʻǤ, ֥롼
   !     et_initial ˤƤ餫ꤷƤ.
   !   *  1  Y ɸγʻֹ,  2  X ɸ
   !     ʻֹǤ (X, Y νǤϤʤ)Ȥ.
   !
   ! * et : 2 ڥȥǡ.
-  !   * ѿμȼ real(8), dimension(-km:km,0:lm). 
+  !   * ѿμȼ real(8), dimension(-km:km,0:lm).
   !   * km, lm Ϥ줾 X, Y κȿǤ, ֥롼
-  !     et_initial ˤƤ餫ꤷƤ. 
+  !     et_initial ˤƤ餫ꤷƤ.
   !   * ڥȥǡγǼΤˤĤƤ...
   !
   ! * x, y : X, Y  1 ʻǡ.
@@ -96,15 +98,15 @@ module et_module
   !      real(8), dimension(0:jm).
   !
   ! * e, t : 1 ڥȥǡ.
-  !   * ѿμȼ real(8), dimension(-km:km) 
+  !   * ѿμȼ real(8), dimension(-km:km)
   !      real(8), dimension(-lm:lm).
   !
   ! * ax, ay : 1 ʻǡ¤ 2 .
-  !   * ѿμȼ real(8), dimension(:,0:im-1) 
+  !   * ѿμȼ real(8), dimension(:,0:im-1)
   !      real(8), dimension(:,0:jm).
   !
   ! * ae, at : 1 ڥȥǡ¤ 2 .
-  !   * ѿμȼ real(8), dimension(:,-km:km) 
+  !   * ѿμȼ real(8), dimension(:,-km:km)
   !      real(8), dimension(:,0:lm).
   !
   ! * et_ ǻϤޤؿ֤ͤϥڥȥǡƱ.
@@ -118,10 +120,10 @@ module et_module
   !
   !== ѿ³
   !
-  !====  
+  !==== 
   !
   ! et_Initial :: ڥȥѴγʻ, ȿ, ΰ礭
-  ! 
+  !
   !==== ɸѿ
   !
   ! x_X, y_Y     ::  ʻɸ(X,Yɸ)Ǽ 1 
@@ -158,6 +160,10 @@ module et_module
   ! x_IntY_yx, x_AvrY_yx :: 2 ʻǡ Y ʬʿ
   ! IntY_y, AvrY_y       :: 1 (Y)ʻǡ Y ʬʿ
   !
+  !==== 
+  !
+  ! Interpolate_et       :: ڥȥǡκɸͤ
+  !
   use dc_message
   use lumatrix
   use ae_module, x_X => g_X, x_X_weight => g_X_Weight, &
@@ -188,11 +194,13 @@ module et_module
   public at_Boundaries_DD, at_Boundaries_DN               ! 
   public at_Boundaries_ND, at_Boundaries_NN               ! 
   public et_LaplaInv_et, ey_Vor2Strm_ey                   ! 
-  public et_Vor2Strm_et, et_Vor2Strm1_et                  ! 
+!!  public et_Vor2Strm_et, et_Vor2Strm1_et                  ! 
 
   public IntYX_yx, y_IntX_yx, x_IntY_yx, IntX_x, IntY_y   ! ʬ
   public AvrYX_yx, y_AvrX_yx, x_AvrY_yx, AvrX_x, AvrY_y   ! ʿ
 
+  public Interpolate_et                                   ! 
+
   integer            :: im=32, jm=8      ! ʻ(X,Y)
   integer            :: km=10, lm=5      ! ȿ(X,Y)
   real(8)            :: xl=2.0, yl=1.0   ! ΰ礭
@@ -230,7 +238,7 @@ module et_module
       yx_X = spread(x_X,1,jm+1)
       yx_Y = spread(y_Y,2,im)
 
-      call MessageNotify('M','et_initial','et_module (2009/07/31) is initialized')
+      call MessageNotify('M','et_initial','et_module (2011/12/03) is initialized')
     end subroutine et_initial
 
   !--------------- Ѵ -----------------
@@ -358,18 +366,18 @@ module et_module
       ! ǥꥯ, ΥޥŬ. ӥն֤Ǥη׻
       !
       ! ºݤˤǸƤФƤ at_module Υ֥롼 at_Boundaries_DD,
-      ! at_Boundaries_DN, at_Boundaries_ND, at_Boundaries_NN ѤƤ. 
+      ! at_Boundaries_DN, at_Boundaries_ND, at_Boundaries_NN ѤƤ.
       ! ľܸƤ֤Ȥ.
       !
       real(8), dimension(-km:km,0:lm),intent(inout)      :: et
-              ! ŬѤǡ. 줿֤ͤ. 
+              ! ŬѤǡ. 줿֤ͤ.
 
       real(8), dimension(-km:km,2), intent(in), optional :: values
-              ! Ǥ / ʬۤʿڥȥѴΤͿ. 
-              ! ά/ 0 Ȥʤ. 
+              ! Ǥ / ʬۤʿڥȥѴΤͿ.
+              ! ά/ 0 Ȥʤ.
 
       character(len=2), intent(in), optional             :: cond
-              ! . ά 'DD'
+              ! . ά 'RR'
               !   DD : ξüǥꥯ
               !   DN,ND : ǥꥯ/Υޥ
               !   NN : ξüΥޥ
@@ -416,7 +424,7 @@ module et_module
 
     function et_LaplaInv_et(et,values)
       !
-      ! ǰͤͤͿ(ǥꥯ), 
+      ! ǰͤͤͿ(ǥꥯ),
       ! ϥڥȥǡ˵եץ饷(xx+yy)**(-1)Ѥ.
       !
       ! Chebyshev-tau ˡˤ׻
@@ -431,7 +439,7 @@ module et_module
       !(out) ڥȥǡεեץ饷
 
       real(8), dimension(-km:km,2), intent(in), optional :: values
-      !(in) . ά 0 ꤵ. 
+      !(in) . ά 0 ꤵ.
 
       real(8), dimension(:,:,:), allocatable  :: alu
       integer, dimension(:,:), allocatable    :: kp
@@ -446,7 +454,7 @@ module et_module
       save    :: alu, kp, first
 
       if (.not. present(values)) then
-         value1=0 ; value2=0
+         value1=0.0D0 ; value2=0.0D0
       else
          value1 = values(:,1) ; value2 = values(:,2)
       endif
@@ -456,15 +464,15 @@ module et_module
 
          allocate(alu(-km:km,0:lm,0:lm),kp(-km:km,0:lm))
 
-         tt_work=0
+         tt_work=0.0D0
          do l=0,lm
-            tt_work(l,l)=1
+            tt_work(l,l)=1.0D0
          enddo
          ty_work=ay_at(tt_work)
 
          do k=-km,km
             alu(k,:,:) = transpose(at_Dy_at(at_Dy_at(tt_work)) &
-                                   - (2*pi*k/xl)**2*tt_work)
+                                   - (2.0D0*pi*k/xl)**2*tt_work)
             alu(k,lm-1,:) = ty_work(:,0)
             alu(k,lm,:)   = ty_work(:,jm)
          enddo
@@ -479,13 +487,13 @@ module et_module
 
     end function et_LaplaInv_et
 
-    function ey_Vor2Strm_ey(ey,values,cond,new)    ! ٤ή. 
+    function ey_Vor2Strm_ey(ey,values,cond,new)    ! ٤ή.
       !
-      ! ٤ή. 
+      ! ٤ή.
       ! Y ʻ֤Ǥ Chebyshev-Collocation ˡˤ׻
       !
       !  \zeta Ϳή \psi .
-      !    \nabla^2 \psi = \zeta, 
+      !    \nabla^2 \psi = \zeta,
       !    \psi = const. at boundaries.
       ! Ǵ
       !    \DP{\psi}{y} = 0 at boundaries
@@ -501,7 +509,7 @@ module et_module
 
       real(8), dimension(2), intent(in), optional :: values
               !(in) ή. ǰʤΤȿ 0 ʬΤ
-	      !     ά 0.
+              !     ά 0.
 
       character(len=2), intent(in), optional  :: cond
               ! (in) 凉å. ά 'RR'
@@ -520,7 +528,8 @@ module et_module
       real(8), dimension(0:jm,0:jm)           :: yy
       real(8), dimension(0:jm,0:jm)           :: yy_work
       real(8)                                 :: value1, value2   ! 
-      logical                                 :: rigid1, rigid2   ! 
+      logical                                 :: rigid1 = .true.
+      logical                                 :: rigid2 = .true.
 
       logical :: first = .true.
       logical :: new_matrix = .false.
@@ -528,31 +537,27 @@ module et_module
       save    :: alu, kp, first
 
       if (.not. present(values)) then
-         value1=0 ; value2=0
+        value1=0.0D0 ; value2=0.0D0
       else
-         value1 = values(1) ; value2 = values(2)
+        value1 = values(1) ; value2 = values(2)
       endif
 
-      if (.not. present(cond)) then
-         rigid1=.TRUE. ; rigid2=.TRUE.
-      else
-         select case (cond)
-         case ('RR')
-            rigid1 = .TRUE.  ; rigid2 = .TRUE.
-         case ('RF')
-            rigid1 = .TRUE.  ; rigid2 = .FALSE.
-         case ('FR')
-            rigid1 = .FALSE. ; rigid2 = .TRUE.
-         case ('FF')
-            rigid1 = .FALSE. ; rigid2 = .FALSE.
-         case default
-            call MessageNotify('E','ey_Vor2Strm_ey','B.C. not supported')
-         end select
-      endif
+      select case (cond)
+      case ('RR')
+        rigid1 = .TRUE.  ; rigid2 = .TRUE.
+      case ('RF')
+        rigid1 = .TRUE.  ; rigid2 = .FALSE.
+      case ('FR')
+        rigid1 = .FALSE. ; rigid2 = .TRUE.
+      case ('FF')
+        rigid1 = .FALSE. ; rigid2 = .FALSE.
+      case default
+        call MessageNotify('E','ey_Vor2Strm_ey','B.C. not supported')
+      end select
 
       if (.not. present(new)) then
          new_matrix=.false.
-      else 
+      else
          new_matrix=new
       endif
 
@@ -563,14 +568,13 @@ module et_module
          if ( allocated(kp) ) deallocate(kp)
          allocate(alu(-km:km,0:jm,0:jm),kp(-km:km,0:jm))
 
-         yy=0
+         yy=0.0D0
          do j=0,jm
-            yy(j,j)=1
+            yy(j,j)=1.0D0
          enddo
          do k=-km,km
             alu(k,:,:) = transpose( &
-                 ay_at(at_Dy_at(at_Dy_at(at_ay(yy)))) &
-                 - (2*pi*k/xl)** 2* yy )
+              ay_at(at_Dy_at(at_Dy_at(at_ay(yy)))) - (2.0D0*pi*k/xl)**2*yy )
          enddo
 
          ! ưŪ. ή϶ǰ
@@ -580,7 +584,7 @@ module et_module
             alu(k,jm,:)  = yy_work(:,jm)
          enddo
 
-         ! ϳŪǴ 
+         ! ϳŪǴ
          if ( rigid1 ) then
             yy_work=ay_at(at_Dy_at(at_ay(yy)))
          else
@@ -590,7 +594,7 @@ module et_module
             alu(k,1,:) = yy_work(:,0)
          enddo
 
-         ! ϳŪǴ 
+         ! ϳŪǴ
          if ( rigid2 ) then
             yy_work=ay_at(at_Dy_at(at_ay(yy)))
          else
@@ -607,256 +611,256 @@ module et_module
       endif
 
       ey_work = ey
-      ey_work(:,1)    = 0               ! ϳŪ
-      ey_work(:,jm-1) = 0               ! ϳŪ
+      ey_work(:,1)    = 0.0D0               ! ϳŪ
+      ey_work(:,jm-1) = 0.0D0               ! ϳŪ
 
-      ey_work(:,0) = 0            ! ưŪ. ȿ 0 ʳ 0 
-      ey_work(0,0) = value1*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+      ey_work(:,0) = 0.0D0                  ! ưŪ. ȿ 0 ʳ 0
+      ey_work(0,0) = value1*2.0D0           ! ưŪ. ȿ 0 ϽŤ 1/2
 
-      ey_work(:,jm)   = 0            ! ưŪ. ȿ 0 ʳ 0 
-      ey_work(0,jm)   = value2*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+      ey_work(:,jm)   = 0.0D0               ! ưŪ. ȿ 0 ʳ 0
+      ey_work(0,jm)   = value2*2.0D0        ! ưŪ. ȿ 0 ϽŤ 1/2
 
       ey_Vor2Strm_ey = lusolve(alu,kp,ey_work)
 
     end function ey_Vor2Strm_ey
 
-   !-----   : ׻ޤ. pending ---- 
-    function et_Vor2Strm_et(et,values,rigid)
-      !
-      ! ٤ή. 
-      !
-      !  : ʲޤʤα. Ѷػ
-      !    * Y ȿ lm=jm ꤷƤʤ
-      !      ׻̤ư԰Ȥʤ.
-      !    *  󰵽ήη׻γȻλȯŸ˷׻Ǥʤ. 
-      !       Chebyshev-tauȤɤʤ餷.
-      !
-      ! Chebyshev-tau ˡˤ׻
-      !  \zeta Ϳή \psi .
-      !    \nabla^2 \psi = \zeta, 
-      !    \psi = const. at boundaries.
-      ! Ǵ
-      !    \DP{\psi}{y} = 0 at boundaries
-      ! Ϥʤ
-      !    \DP[2]{\psi}{y} = 0 at boundaries
-      !
-      ! l=0,1,lm-1,lm ʬμ˶Ϳ. 
-      ! ٤㼡ʬ̵뤹뤳Ȥ
-      ! \nabla^4 \psi = \zeta^2 򤤤Ƥ뤳Ȥ. 
-      ! 4 ʬˤ뤳ȤǶοȤĤĤޤ. 
-
-      real(8), dimension(-km:km,0:lm),intent(in)  :: et
-      real(8), dimension(-km:km,0:lm)             :: et_Vor2Strm_et
-
-      ! ή. ǰʤΤȿ 0 ʬΤ
-      real(8), dimension(2), intent(in), optional :: values
-      ! 凉å
-      logical, dimension(2), intent(in), optional :: rigid
-
-      real(8), dimension(:,:,:), allocatable  :: alu
-      integer, dimension(:,:), allocatable    :: kp
-
-      real(8), dimension(-km:km,0:lm)         :: et_work
-      real(8), dimension(0:lm,0:lm)           :: tt_work
-      real(8), dimension(0:lm,0:jm)           :: ty_work
-      real(8)                                 :: value1, value2   ! 
-      logical                                 :: rigid1, rigid2   ! 
-
-      logical :: first = .true.
-      integer :: k,l
-      save    :: alu, kp, first
-
-      if (.not. present(values)) then
-         value1=0 ; value2=0
-      else
-         value1 = values(1) ; value2 = values(2)
-      endif
-
-      if (.not. present(rigid)) then
-         rigid1=.true. ; rigid2=.true.
-      else
-         rigid1 = rigid(1) ; rigid2 = rigid(2)
-      endif
-
-      if ( first ) then
-         first = .false.
-
-         allocate(alu(-km:km,0:lm,0:lm),kp(-km:km,0:lm))
-
-         tt_work=0
-         do l=0,lm
-            tt_work(l,l)=1
-         enddo
-         do k=-km,km
-            alu(k,:,:) = transpose(at_Dy_at(at_Dy_at(tt_work)) &
-                                   - (2*pi*k/xl)**2*tt_work)
-         enddo
-
-         ! ưŪ. ή϶ǰ
-         ty_work=ay_at(tt_work)
-         do k=-km,km
-            alu(k,lm-1,:) = ty_work(:,0)
-            alu(k,lm,:)   = ty_work(:,jm)
-         enddo
-
-         ! ϳŪǴ 
-         if ( rigid1 ) then
-            ty_work=ay_at(at_Dy_at(tt_work))
-         else
-            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
-         endif
-         do k=-km,km
-            alu(k,0,:) = ty_work(:,0)
-         enddo
-
-         ! ϳŪǴ 
-         if ( rigid2 ) then
-            ty_work=ay_at(at_Dy_at(tt_work))
-         else
-            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
-         endif
-         do k=-km,km
-            alu(k,1,:) = ty_work(:,jm)
-         enddo
-
-         call ludecomp(alu,kp)
-      endif
-
-      et_work = et
-      et_work(:,0) = 0               ! ϳŪ
-      et_work(:,1) = 0               ! ϳŪ
-
-      et_work(:,lm-1) = 0            ! ưŪ. ȿ 0 ʳ 0 
-      et_work(0,lm-1) = value1*2     ! ưŪ. ȿ 0 ϽŤ 1/2
-
-      et_work(:,lm)   = 0            ! ưŪ. ȿ 0 ʳ 0 
-      et_work(0,lm)   = value2*2     ! ưŪ. ȿ 0 ϽŤ 1/2
-
-      et_Vor2Strm_et = lusolve(alu,kp,et_work)
-
-    end function et_Vor2Strm_et
-
-   !-----   : ׻ޤ. pending ---- 
-    function et_Vor2Strm1_et(et,values,rigid) 
-      ! ٤ή. 
-      !
-      !  : ʲޤʤα. Ѷػ
-      !    * Y ȿ lm=jm ꤷƤʤ
-      !      ׻̤ư԰Ȥʤ.
-      !    *  󰵽ήη׻γȻλȯŸ˷׻Ǥʤ. 
-      !       Chebyshev-tauȤɤʤ餷.
-      !
-      ! Chebyshev-tau ˡˤ׻
-      !  \zeta Ϳή \psi .
-      !    \nabla^2 \psi = \zeta, 
-      !    \psi = const. at boundaries.
-      ! Ǵ
-      !    \DP{\psi}{y} = 0 at boundaries
-      ! Ϥʤ
-      !    \DP[2]{\psi}{y} = 0 at boundaries
-      !
-      ! ǥեȤǴ
-      !
-      ! \nabla^4 \psi = \nabla^2\zeta 
-      ! 4 ʬˤ뤳ȤǶοȤĤĤޤ. 
-      !
-      !
-      real(8), dimension(-km:km,0:lm),intent(in)  :: et
-      !(in) 
-
-      real(8), dimension(-km:km,0:lm)             :: et_Vor2Strm1_et
-      !(out)  ή. ǰʤΤȿ 0 ʬΤ
-
-      real(8), dimension(2), intent(in), optional :: values
-      !(in) 凉å
-
-      logical, dimension(2), intent(in), optional :: rigid
-
-      real(8), dimension(:,:,:), allocatable  :: alu
-      integer, dimension(:,:), allocatable    :: kp
-
-      real(8), dimension(-km:km,0:lm)         :: et_work
-      real(8), dimension(0:lm,0:lm)           :: tt_work
-      real(8), dimension(0:lm,0:jm)           :: ty_work
-      real(8)                                 :: value1, value2   ! 
-      logical                                 :: rigid1, rigid2   ! 
-
-      logical :: first = .true.
-      integer :: k,l
-      save    :: alu, kp, first
-
-      if (.not. present(values)) then
-         value1=0 ; value2=0
-      else
-         value1 = values(1) ; value2 = values(2)
-      endif
-
-      if (.not. present(rigid)) then
-         rigid1=.true. ; rigid2=.true.
-      else
-         rigid1 = rigid(1) ; rigid2 = rigid(2)
-      endif
-
-      if ( first ) then
-         first = .false.
-
-         allocate(alu(-km:km,0:lm,0:lm),kp(-km:km,0:lm))
-
-         tt_work=0
-         do l=0,lm
-            tt_work(l,l)=1
-         enddo
-         do k=-km,km
-            alu(k,:,:) = transpose( &
-                 at_Dy_at(at_Dy_at(at_Dy_at(at_Dy_at(tt_work)))) &
-                 - 2 * (2*pi*k/xl)**2 * at_Dy_at(at_Dy_at(tt_work)) &
-                 + (2*pi*k/xl)**4*tt_work &
-                 )
-         enddo
-
-         ! ưŪ. ή϶ǰ
-         ty_work=ay_at(tt_work)
-         do k=-km,km
-            alu(k,lm-1,:) = ty_work(:,0)
-            alu(k,lm,:)   = ty_work(:,jm)
-         enddo
-
-         ! ϳŪǴ 
-         if ( rigid1 ) then
-            ty_work=ay_at(at_Dy_at(tt_work))
-         else
-            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
-         endif
-         do k=-km,km
-            alu(k,lm-3,:) = ty_work(:,0)
-         enddo
-
-         ! ϳŪǴ 
-         if ( rigid2 ) then
-            ty_work=ay_at(at_Dy_at(tt_work))
-         else
-            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
-         endif
-         do k=-km,km
-            alu(k,lm-2,:) = ty_work(:,jm)
-         enddo
-
-         call ludecomp(alu,kp)
-      endif
-
-      et_work = et_Lapla_et(et)
-      et_work(:,lm-3) = 0               ! ϳŪ
-      et_work(:,lm-2) = 0               ! ϳŪ
-
-      et_work(:,lm-1) = 0            ! ưŪ. ȿ 0 ʳ 0 
-      et_work(0,lm-1) = value1*2     ! ưŪ. ȿ 0 ϽŤ 1/2
-
-      et_work(:,lm)   = 0            ! ưŪ. ȿ 0 ʳ 0 
-      et_work(0,lm)   = value2*2     ! ưŪ. ȿ 0 ϽŤ 1/2
-
-      et_Vor2Strm1_et = lusolve(alu,kp,et_work)
-
-    end function et_Vor2Strm1_et
+!!   !-----   : ׻ޤ. pending ----
+!!    function et_Vor2Strm_et(et,values,rigid)
+!!      !
+!!      ! ٤ή.
+!!      !
+!!      !  : ʲޤʤα. Ѷػ
+!!      !    * Y ȿ lm=jm ꤷƤʤ
+!!      !      ׻̤ư԰Ȥʤ.
+!!      !    *  󰵽ήη׻γȻλȯŸ˷׻Ǥʤ.
+!!      !       Chebyshev-tauȤɤʤ餷.
+!!      !
+!!      ! Chebyshev-tau ˡˤ׻
+!!      !  \zeta Ϳή \psi .
+!!      !    \nabla^2 \psi = \zeta,
+!!      !    \psi = const. at boundaries.
+!!      ! Ǵ
+!!      !    \DP{\psi}{y} = 0 at boundaries
+!!      ! Ϥʤ
+!!      !    \DP[2]{\psi}{y} = 0 at boundaries
+!!      !
+!!      ! l=0,1,lm-1,lm ʬμ˶Ϳ.
+!!      ! ٤㼡ʬ̵뤹뤳Ȥ
+!!      ! \nabla^4 \psi = \zeta^2 򤤤Ƥ뤳Ȥ.
+!!      ! 4 ʬˤ뤳ȤǶοȤĤĤޤ.
+!!
+!!      real(8), dimension(-km:km,0:lm),intent(in)  :: et
+!!      real(8), dimension(-km:km,0:lm)             :: et_Vor2Strm_et
+!!
+!!      ! ή. ǰʤΤȿ 0 ʬΤ
+!!      real(8), dimension(2), intent(in), optional :: values
+!!      ! 凉å
+!!      logical, dimension(2), intent(in), optional :: rigid
+!!
+!!      real(8), dimension(:,:,:), allocatable  :: alu
+!!      integer, dimension(:,:), allocatable    :: kp
+!!
+!!      real(8), dimension(-km:km,0:lm)         :: et_work
+!!      real(8), dimension(0:lm,0:lm)           :: tt_work
+!!      real(8), dimension(0:lm,0:jm)           :: ty_work
+!!      real(8)                                 :: value1, value2   ! 
+!!      logical                                 :: rigid1, rigid2   ! 
+!!
+!!      logical :: first = .true.
+!!      integer :: k,l
+!!      save    :: alu, kp, first
+!!
+!!      if (.not. present(values)) then
+!!         value1=0 ; value2=0
+!!      else
+!!         value1 = values(1) ; value2 = values(2)
+!!      endif
+!!
+!!      if (.not. present(rigid)) then
+!!         rigid1=.true. ; rigid2=.true.
+!!      else
+!!         rigid1 = rigid(1) ; rigid2 = rigid(2)
+!!      endif
+!!
+!!      if ( first ) then
+!!         first = .false.
+!!
+!!         allocate(alu(-km:km,0:lm,0:lm),kp(-km:km,0:lm))
+!!
+!!         tt_work=0
+!!         do l=0,lm
+!!            tt_work(l,l)=1
+!!         enddo
+!!         do k=-km,km
+!!            alu(k,:,:) = transpose(at_Dy_at(at_Dy_at(tt_work)) &
+!!                                   - (2*pi*k/xl)**2*tt_work)
+!!         enddo
+!!
+!!         ! ưŪ. ή϶ǰ
+!!         ty_work=ay_at(tt_work)
+!!         do k=-km,km
+!!            alu(k,lm-1,:) = ty_work(:,0)
+!!            alu(k,lm,:)   = ty_work(:,jm)
+!!         enddo
+!!
+!!         ! ϳŪǴ
+!!         if ( rigid1 ) then
+!!            ty_work=ay_at(at_Dy_at(tt_work))
+!!         else
+!!            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
+!!         endif
+!!         do k=-km,km
+!!            alu(k,0,:) = ty_work(:,0)
+!!         enddo
+!!
+!!         ! ϳŪǴ
+!!         if ( rigid2 ) then
+!!            ty_work=ay_at(at_Dy_at(tt_work))
+!!         else
+!!            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
+!!         endif
+!!         do k=-km,km
+!!            alu(k,1,:) = ty_work(:,jm)
+!!         enddo
+!!
+!!         call ludecomp(alu,kp)
+!!      endif
+!!
+!!      et_work = et
+!!      et_work(:,0) = 0               ! ϳŪ
+!!      et_work(:,1) = 0               ! ϳŪ
+!!
+!!      et_work(:,lm-1) = 0            ! ưŪ. ȿ 0 ʳ 0
+!!      et_work(0,lm-1) = value1*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+!!
+!!      et_work(:,lm)   = 0            ! ưŪ. ȿ 0 ʳ 0
+!!      et_work(0,lm)   = value2*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+!!
+!!      et_Vor2Strm_et = lusolve(alu,kp,et_work)
+!!
+!!    end function et_Vor2Strm_et
+!!
+!!   !-----   : ׻ޤ. pending ----
+!!    function et_Vor2Strm1_et(et,values,rigid)
+!!      ! ٤ή.
+!!      !
+!!      !  : ʲޤʤα. Ѷػ
+!!      !    * Y ȿ lm=jm ꤷƤʤ
+!!      !      ׻̤ư԰Ȥʤ.
+!!      !    *  󰵽ήη׻γȻλȯŸ˷׻Ǥʤ.
+!!      !       Chebyshev-tauȤɤʤ餷.
+!!      !
+!!      ! Chebyshev-tau ˡˤ׻
+!!      !  \zeta Ϳή \psi .
+!!      !    \nabla^2 \psi = \zeta,
+!!      !    \psi = const. at boundaries.
+!!      ! Ǵ
+!!      !    \DP{\psi}{y} = 0 at boundaries
+!!      ! Ϥʤ
+!!      !    \DP[2]{\psi}{y} = 0 at boundaries
+!!      !
+!!      ! ǥեȤǴ
+!!      !
+!!      ! \nabla^4 \psi = \nabla^2\zeta 
+!!      ! 4 ʬˤ뤳ȤǶοȤĤĤޤ.
+!!      !
+!!      !
+!!      real(8), dimension(-km:km,0:lm),intent(in)  :: et
+!!      !(in) 
+!!
+!!      real(8), dimension(-km:km,0:lm)             :: et_Vor2Strm1_et
+!!      !(out)  ή. ǰʤΤȿ 0 ʬΤ
+!!
+!!      real(8), dimension(2), intent(in), optional :: values
+!!      !(in) 凉å
+!!
+!!      logical, dimension(2), intent(in), optional :: rigid
+!!
+!!      real(8), dimension(:,:,:), allocatable  :: alu
+!!      integer, dimension(:,:), allocatable    :: kp
+!!
+!!      real(8), dimension(-km:km,0:lm)         :: et_work
+!!      real(8), dimension(0:lm,0:lm)           :: tt_work
+!!      real(8), dimension(0:lm,0:jm)           :: ty_work
+!!      real(8)                                 :: value1, value2   ! 
+!!      logical                                 :: rigid1, rigid2   ! 
+!!
+!!      logical :: first = .true.
+!!      integer :: k,l
+!!      save    :: alu, kp, first
+!!
+!!      if (.not. present(values)) then
+!!         value1=0 ; value2=0
+!!      else
+!!         value1 = values(1) ; value2 = values(2)
+!!      endif
+!!
+!!      if (.not. present(rigid)) then
+!!         rigid1=.true. ; rigid2=.true.
+!!      else
+!!         rigid1 = rigid(1) ; rigid2 = rigid(2)
+!!      endif
+!!
+!!      if ( first ) then
+!!         first = .false.
+!!
+!!         allocate(alu(-km:km,0:lm,0:lm),kp(-km:km,0:lm))
+!!
+!!         tt_work=0
+!!         do l=0,lm
+!!            tt_work(l,l)=1
+!!         enddo
+!!         do k=-km,km
+!!            alu(k,:,:) = transpose( &
+!!                 at_Dy_at(at_Dy_at(at_Dy_at(at_Dy_at(tt_work)))) &
+!!                 - 2 * (2*pi*k/xl)**2 * at_Dy_at(at_Dy_at(tt_work)) &
+!!                 + (2*pi*k/xl)**4*tt_work &
+!!                 )
+!!         enddo
+!!
+!!         ! ưŪ. ή϶ǰ
+!!         ty_work=ay_at(tt_work)
+!!         do k=-km,km
+!!            alu(k,lm-1,:) = ty_work(:,0)
+!!            alu(k,lm,:)   = ty_work(:,jm)
+!!         enddo
+!!
+!!         ! ϳŪǴ
+!!         if ( rigid1 ) then
+!!            ty_work=ay_at(at_Dy_at(tt_work))
+!!         else
+!!            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
+!!         endif
+!!         do k=-km,km
+!!            alu(k,lm-3,:) = ty_work(:,0)
+!!         enddo
+!!
+!!         ! ϳŪǴ
+!!         if ( rigid2 ) then
+!!            ty_work=ay_at(at_Dy_at(tt_work))
+!!         else
+!!            ty_work=ay_at(at_Dy_at(at_Dy_at(tt_work)))
+!!         endif
+!!         do k=-km,km
+!!            alu(k,lm-2,:) = ty_work(:,jm)
+!!         enddo
+!!
+!!         call ludecomp(alu,kp)
+!!      endif
+!!
+!!      et_work = et_Lapla_et(et)
+!!      et_work(:,lm-3) = 0               ! ϳŪ
+!!      et_work(:,lm-2) = 0               ! ϳŪ
+!!
+!!      et_work(:,lm-1) = 0            ! ưŪ. ȿ 0 ʳ 0
+!!      et_work(0,lm-1) = value1*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+!!
+!!      et_work(:,lm)   = 0            ! ưŪ. ȿ 0 ʳ 0
+!!      et_work(0,lm)   = value2*2     ! ưŪ. ȿ 0 ϽŤ 1/2
+!!
+!!      et_Vor2Strm1_et = lusolve(alu,kp,et_work)
+!!
+!!    end function et_Vor2Strm1_et
 
   !--------------- ʬ׻ -----------------
     function IntYX_yx(yx)   ! ΰʬ
@@ -864,7 +868,7 @@ module et_module
       ! 2 ʻǡΰʬʿ.
       !
       ! ºݤˤϳʻǡ x_X_Weight, y_Y_Weight 򤫤
-      ! ¤׻Ƥ. 
+      ! ¤׻Ƥ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in)  2 ʻǡ
@@ -886,7 +890,7 @@ module et_module
       !
       ! 2 ʻǡ X ʬ
       !
-      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻Ƥ. 
+      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻Ƥ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in) 2 ʻǡ
@@ -907,7 +911,7 @@ module et_module
       !
       ! 2 ʻǡ Y ʬ
       !
-      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻Ƥ. 
+      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻Ƥ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in)  2 ʻǡ
@@ -928,7 +932,7 @@ module et_module
       !
       ! 1 (X)ʻǡ X ʬ
       !
-      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻Ƥ. 
+      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻Ƥ.
       !
       real(8), dimension(0:im-1)   :: x         !(in)  1 ʻǡ
       real(8)                      :: IntX_x    !(out) ʬ
@@ -940,7 +944,7 @@ module et_module
       !
       ! 1 (Y)ʻǡ Y ʬ
       !
-      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻Ƥ. 
+      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻Ƥ.
       !
       real(8), dimension(0:jm)   :: y          !(in)  1 ʻǡ
       real(8)                    :: IntY_y     !(out) ʬ
@@ -954,7 +958,7 @@ module et_module
       ! 2 ʻǡΰʿ
       !
       ! ºݤˤϳʻǡ x_X_Weight, y_Y_Weight 򤫤
-      ! ¤׻, x_X_Weight*y_Y_Weight ¤ǳ뤳ȤʿѤƤ. 
+      ! ¤׻, x_X_Weight*y_Y_Weight ¤ǳ뤳ȤʿѤƤ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in)  2 ʻǡ
@@ -969,8 +973,8 @@ module et_module
       !
       ! 2 ʻǡ X ʿ
       !
-      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻, 
-      ! x_X_Weight ¤ǳ뤳ȤʿѤƤ. 
+      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻,
+      ! x_X_Weight ¤ǳ뤳ȤʿѤƤ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in) 2 ʻǡ
@@ -985,8 +989,8 @@ module et_module
       !
       ! 2 ʻǡ Y ʿ
       !
-      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻, 
-      ! y_Y_Weight ¤ǳ뤳ȤʿѤƤ. 
+      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻,
+      ! y_Y_Weight ¤ǳ뤳ȤʿѤƤ.
       !
       real(8), dimension(0:jm,0:im-1)   :: yx
       !(in) 2 ʻǡ
@@ -1001,8 +1005,8 @@ module et_module
       !
       ! 1 (X)ʻǡ X ʿ
       !
-      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻, 
-      ! x_X_Weight ¤ǳ뤳ȤʿѤƤ. 
+      ! ºݤˤϳʻǡ x_X_Weight 򤫤¤׻,
+      ! x_X_Weight ¤ǳ뤳ȤʿѤƤ.
       !
       real(8), dimension(0:im-1)   :: x          !(in)  1 ʻǡ
       real(8)                      :: AvrX_x     !(out) ʿ
@@ -1014,8 +1018,8 @@ module et_module
       !
       ! 1 (Y)ʻǡ Y ʿ
       !
-      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻, 
-      ! y_Y_Weight ¤ǳ뤳ȤʿѤƤ. 
+      ! ºݤˤϳʻǡ y_Y_Weight 򤫤¤׻,
+      ! y_Y_Weight ¤ǳ뤳ȤʿѤƤ.
       !
       real(8), dimension(0:jm)   :: y          !(in)  1 ʻǡ
       real(8)                    :: AvrY_y     !(out) ʿ
@@ -1023,4 +1027,20 @@ module et_module
       AvrY_y = IntY_y(y)/sum(y_Y_weight)
     end function AvrY_y
 
+  !--------------------- ִؿ ---------------------------
+    function Interpolate_et(et_data,xval,yval)
+
+      real(8), dimension(-km:km,0:lm), intent(IN) :: et_data
+      !(in) ϥաꥨǡ
+
+      real(8), intent(in)                         :: xval, yval
+      ! ֤ X, Y ɸ
+
+      real(8)                                     :: Interpolate_et
+      ! ֤̤
+
+      Interpolate_et = Interpolate_e(a_Interpolate_at(et_data,yval),xval)
+
+    end function Interpolate_et
+
   end module et_module
