@@ -1,6 +1,6 @@
 !--
 !----------------------------------------------------------------------
-! Copyright(c) 2009-2010 SPMDODEL Development Group. All rights reserved.
+! Copyright(c) 2009-2011 SPMDODEL Development Group. All rights reserved.
 !----------------------------------------------------------------------
 !
 !ɽ  et_module_fftj
@@ -19,6 +19,7 @@
 !
 !  2009/09/10  ݹ  et_module.f90  fftj Ѥ˲¤
 !      2010/03/10  ʿ  threadprivate (ѥ¸)
+!      2011/12/03  ݹ  ִؿɲ
 !
 !++
 module et_module_fftj
@@ -147,6 +148,10 @@ module et_module_fftj
   ! x_IntY_yx, x_AvrY_yx :: 2 ʻǡ Y ʬʿ
   ! IntY_y, AvrY_y       :: 1 (Y)ʻǡ Y ʬʿ
   !
+  !==== 
+  !
+  ! Interpolate_et       :: ڥȥǡκɸͤ
+  !
   use dc_message
   use lumatrix
   use ae_module_fftj, x_X => g_X, x_X_weight => g_X_Weight, &
@@ -182,6 +187,8 @@ module et_module_fftj
   public IntYX_yx, y_IntX_yx, x_IntY_yx, IntX_x, IntY_y   ! ʬ
   public AvrYX_yx, y_AvrX_yx, x_AvrY_yx, AvrX_x, AvrY_y   ! ʿ
 
+  public Interpolate_et                                   ! 
+
   integer            :: im=32, jm=8      ! ʻ(X,Y)
   integer            :: km=10, lm=5      ! ȿ(X,Y)
   real(8)            :: xl=2.0, yl=1.0   ! ΰ礭
@@ -220,7 +227,7 @@ module et_module_fftj
       yx_Y = spread(y_Y,2,im)
 
       call MessageNotify('M','et_initial',&
-           'et_module_fftj (2009/09/10) is initialized')
+           'et_module_fftj (2011/12/03) is initialized')
 
     end subroutine et_initial
 
@@ -1014,4 +1021,20 @@ module et_module_fftj
       AvrY_y = IntY_y(y)/sum(y_Y_weight)
     end function AvrY_y
 
+  !--------------------- ִؿ ---------------------------
+    function Interpolate_et(et_data,xval,yval)
+
+      real(8), dimension(-km:km,0:lm), intent(IN) :: et_data
+      !(in) ϥաꥨǡ
+
+      real(8), intent(in)                         :: xval, yval
+      ! ֤ X, Y ɸ
+
+      real(8)                                     :: Interpolate_et
+      ! ֤̤
+
+      Interpolate_et = Interpolate_e(a_Interpolate_at(et_data,yval),xval)
+
+    end function Interpolate_et
+
 end module et_module_fftj
